<?php
// Add header image
if ( ! function_exists( 'amiable_custom_header_image' ) ) :
	function amiable_custom_header_image( $value ) {
		if ( get_header_image() ) {
			echo '<div class="site-header-image">';
			echo '<img class="header-image" src="'.get_header_image().'" width="'.get_custom_header()->width.'" height="'.get_custom_header()->height.'" alt="Custom header added to site" />';
			echo '</div>';
		}
	}
endif;
add_filter( 'amiable_header_image', 'amiable_custom_header_image' );

// Add format image, date, author and comment info to articles on blog pages
if ( ! function_exists( 'amiable_entry_header_meta' ) ) :
function amiable_entry_header_meta() {
	
	if ( is_sticky() ):
		$sticky = __('Featured', 'amiable');
		echo '<span class="post-sticky">' . $sticky . '</span>';
	endif;
	
	$format = get_post_format();
	if ( current_theme_supports( 'post-formats', $format ) ) {
		printf( '<span class="entry-format">%1$s<a href="%2$s">%3$s</a></span>',
			sprintf( '<span class="screen-reader-text">%s</span>', esc_html_x( 'Format', '', 'amiable' ) ),
			esc_url( get_post_format_link( $format ) ),
			get_post_format_string( $format )
		);
	}
	
	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);
		$title = get_the_title();
		if ($title !=''):
			printf( '<span class="post-date">' . $time_string . '</span>');
		else:
			printf( '<span class="post-date">%1$s<a href="%2$s" rel="bookmark">%3$s</a></span>',
			sprintf( _x( '<span class="screen-reader-text">Posted on</span>', '', 'amiable' ) ),
			esc_url( get_permalink() ),
			$time_string
			);
		endif;
	}

	if ( 'post' == get_post_type() ) {
		if ( is_singular() || is_multi_author() ) {
			printf( '<span class="byline"><span class="post-author vcard">%1$s<a class="url fn n" href="%2$s">%3$s</a></span></span>',
				sprintf( _x( '<span class="screen-reader-text">Author</span>', '', 'amiable' ) ),
				esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
				esc_html( get_the_author() )
			);
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="post-comment">';
		comments_popup_link( esc_html__( 'Leave a response', 'amiable' ), esc_html__( '1 Response', 'amiable' ), esc_html__( '% Responses', 'amiable' ) );
		echo '</span>';
	}
}

endif;

// Add date to top of article on single pages
if ( ! function_exists( 'amiable_entry_header_meta_single' ) ) :

	function amiable_entry_header_meta_single() {
		if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() )
			);
			$title = get_the_title();
			if ($title !=''):
				printf( '<span class="post-date">' . $time_string . '</span>');
			else:
				printf( '<span class="post-date">%1$s<a href="%2$s" rel="bookmark">%3$s</a></span>',
				sprintf( _x( '<span class="screen-reader-text">Posted on</span>', '', 'amiable' ) ),
				esc_url( get_permalink() ),
				$time_string
				);
			endif;
		}
	}
	
endif;

// Add categories and tags to articles on blog and single pages
if ( ! function_exists( 'amiable_entry_footer_meta' ) ) :

	function amiable_entry_footer_meta() {
		
		if ( 'post' == get_post_type() ) {

		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'amiable' ) );
		
		if ( $categories_list && amiable_categorized_blog() ) {
			printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Categories', 'Used before category names.', 'amiable' ),
				$categories_list
			);
		}

		$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'amiable' ) );
		
		if ( $tags_list ) {
			printf( '<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Tags', 'Used before tag names.', 'amiable' ),
				$tags_list
			);
		}
		
		}
		
	}

endif;

// Determine if blog is using at least two categories or not
if ( ! function_exists( 'amiable_categorized_blog' ) ) :
	
	function amiable_categorized_blog() {
		if ( false === ( $all_the_cool_cats = get_transient( 'amiable_categories' ) ) ) {
			$all_the_cool_cats = get_categories( array(
				'fields'     => 'ids',
				'hide_empty' => 1,
	
				'number'     => 2,
			) );
	
			$all_the_cool_cats = count( $all_the_cool_cats );
	
			set_transient( 'amiable_categories', $all_the_cool_cats );
		}
	
		if ( $all_the_cool_cats > 1 ) {
			return true;
		} else {
			return false;
		}
	}

endif;

// Flush out the transients used in {@see amiable_categorized_blog()}.
function amiable_category_transient_flusher() {
	delete_transient( 'amiable_categories' );
}
add_action( 'edit_category', 'amiable_category_transient_flusher' );
add_action( 'save_post',     'amiable_category_transient_flusher' );


//Add content to article in blog pages if no excerpt or else show the excerpt
if ( ! function_exists( 'amiable_content_excerpt' ) ) :
	
	function amiable_content_excerpt() {
		
		global $post;

		if ( empty( $post->post_excerpt ) ) {
			the_content( sprintf(__( 'Continue reading %s <span class="meta-nav">&rarr;</span>', 'amiable' ), the_title( '<span class="screen-reader-text">"', '"</span>', false )) );
		
			wp_link_pages( array(
				'before'      => '<div class="page-links"><span class="page-links-title">' . __( 'Pages:', 'amiable' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span class="page-link-number">',
				'link_after'  => '</span>',
				'pagelink'    => '<span class="screen-reader-text">' . __( 'Page', 'amiable' ) . ' </span>%',
				'separator'   => '<span class="screen-reader-text">, </span>',
			) ); 
		
		} else {
   			
			the_excerpt();
		}

	}

endif;

// Template for comments and pingbacks
if ( ! function_exists( 'amiable_comment' ) ) :
 
	function amiable_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
	
		if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>
	
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
			<div class="comment-body">
				<?php _e( 'Pingback:', 'amiable' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'amiable' ), '<span class="edit-link">', '</span>' ); ?>
			</div>
	
		<?php else : ?>
	
		<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
			<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
				<footer class="comment-meta">
					<div class="comment-author vcard">
						<?php if ( 0 != $args['avatar_size'] ) { echo get_avatar( $comment, $args['avatar_size'], '', 'Gravatar of ' .  get_comment_author() . ' who made comment number ' . get_comment_ID() ); } ?>
						<?php printf( __( '%s <span class="says">says:</span>', 'amiable' ), sprintf( '<cite class="fn"><span class="external">%s</span></cite>', get_comment_author_link() ));  ?>
					</div><!-- close .comment-author -->
	
					<div class="comment-metadata">
							<time datetime="<?php comment_time( 'c' ); ?>">
								<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'amiable' ), get_comment_date(), get_comment_time() ); ?>
							</time>
						<?php edit_comment_link( __( 'Edit', 'amiable' ), '<span class="edit-link">', '</span>' ); ?>
					</div><!-- close .comment-metadata -->
	
					<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'amiable' ); ?></p>
					<?php endif; ?>
				</footer><!-- close .comment-meta -->
	
				<div class="comment-content">
					<?php comment_text(); ?>
				</div><!-- close .comment-content -->
	
				<?php
					comment_reply_link( array_merge( $args, array(
						'add_below' => 'div-comment',
						'depth'     => $depth,
						'max_depth' => $args['max_depth'],
						'before'    => '<div class="reply">',
						'after'     => '</div>',
					) ) );
				?>
			</article><!-- close .comment-body -->
	
	<?php endif;
	
	}
	
endif;